==> beast-privilege-api-2.6.4-GS-20230104.095226-11-sources.jar: com/thebeastshop/privilege/vo/GiftCampaignVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class GiftCampaignVO implements Serializable {
    private Integer id;
    private String name;
    private Date startDate;
    private Date endDate;
    private String remark;
    private Integer status;
    private String systemDefault;
    private String orderChannelCode;
    private String orderType;
    private String orderBusinessType;
    private String memberLevel;
    private Date orderStartDate;
    private Date orderEndDate;
    private Date payStartDate;
    private Date payEndDate;

    private Integer hasJoin;
    private String giftQualification;
    private String thirdPartyInterface;
    private String orderRemark;
    private Boolean isFuzzyMatch;
    private Integer scope;
    private Integer giftWay;
    private Integer randomNum;
    private Integer totalNum;
    private Integer singleLimit;
    private Integer giftCondition;
    private Integer stepRule;
    private Integer createUserId;
    private String createUserName;
    private Date createTime;
    private Date updateTime;



    private List<String> orderChannelCodeList;
    private List<Integer> orderTypeList;
    private List<Integer> orderBusinessTypeList;
    private List<Integer> orderMemberLevelList;
    private List<Integer> giftQualificationList;
    private List<String>  thirdPartyInterfaceList;


    private List<GiftCampaignConditionSkuVO> giftCampaignConditionSkuVOList;
    private List<GiftCampaignRuleSkuVO> giftCampaignRuleSkuVOList;



    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getSystemDefault() {
        return systemDefault;
    }

    public void setSystemDefault(String systemDefault) {
        this.systemDefault = systemDefault;
    }

    public String getOrderChannelCode() {
        return orderChannelCode;
    }

    public void setOrderChannelCode(String orderChannelCode) {
        this.orderChannelCode = orderChannelCode;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderBusinessType() {
        return orderBusinessType;
    }

    public void setOrderBusinessType(String orderBusinessType) {
        this.orderBusinessType = orderBusinessType;
    }

    public String getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(String memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Date getOrderStartDate() {
        return orderStartDate;
    }

    public void setOrderStartDate(Date orderStartDate) {
        this.orderStartDate = orderStartDate;
    }

    public Date getOrderEndDate() {
        return orderEndDate;
    }

    public void setOrderEndDate(Date orderEndDate) {
        this.orderEndDate = orderEndDate;
    }

    public Date getPayStartDate() {
        return payStartDate;
    }

    public void setPayStartDate(Date payStartDate) {
        this.payStartDate = payStartDate;
    }

    public Date getPayEndDate() {
        return payEndDate;
    }

    public void setPayEndDate(Date payEndDate) {
        this.payEndDate = payEndDate;
    }


    public Integer getHasJoin() {
        return hasJoin;
    }

    public void setHasJoin(Integer hasJoin) {
        this.hasJoin = hasJoin;
    }


    public String getGiftQualification() {
        return giftQualification;
    }

    public void setGiftQualification(String giftQualification) {
        this.giftQualification = giftQualification;
    }

    public String getThirdPartyInterface() {
        return thirdPartyInterface;
    }

    public void setThirdPartyInterface(String thirdPartyInterface) {
        this.thirdPartyInterface = thirdPartyInterface;
    }

    public String getOrderRemark() {
        return orderRemark;
    }

    public void setOrderRemark(String orderRemark) {
        this.orderRemark = orderRemark;
    }

    public Boolean getFuzzyMatch() {
        return isFuzzyMatch;
    }

    public void setFuzzyMatch(Boolean fuzzyMatch) {
        isFuzzyMatch = fuzzyMatch;
    }

    public Integer getScope() {
        return scope;
    }

    public void setScope(Integer scope) {
        this.scope = scope;
    }

    public Integer getGiftWay() {
        return giftWay;
    }

    public void setGiftWay(Integer giftWay) {
        this.giftWay = giftWay;
    }

    public Integer getRandomNum() {
        return randomNum;
    }

    public void setRandomNum(Integer randomNum) {
        this.randomNum = randomNum;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getSingleLimit() {
        return singleLimit;
    }

    public void setSingleLimit(Integer singleLimit) {
        this.singleLimit = singleLimit;
    }

    public Integer getGiftCondition() {
        return giftCondition;
    }

    public void setGiftCondition(Integer giftCondition) {
        this.giftCondition = giftCondition;
    }

    public Integer getStepRule() {
        return stepRule;
    }

    public void setStepRule(Integer stepRule) {
        this.stepRule = stepRule;
    }

    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public List<String> getOrderChannelCodeList() {
        return orderChannelCodeList;
    }

    public void setOrderChannelCodeList(List<String> orderChannelCodeList) {
        this.orderChannelCodeList = orderChannelCodeList;
    }

    public List<Integer> getOrderTypeList() {
        return orderTypeList;
    }

    public void setOrderTypeList(List<Integer> orderTypeList) {
        this.orderTypeList = orderTypeList;
    }

    public List<Integer> getOrderBusinessTypeList() {
        return orderBusinessTypeList;
    }

    public void setOrderBusinessTypeList(List<Integer> orderBusinessTypeList) {
        this.orderBusinessTypeList = orderBusinessTypeList;
    }

    public List<Integer> getOrderMemberLevelList() {
        return orderMemberLevelList;
    }

    public void setOrderMemberLevelList(List<Integer> orderMemberLevelList) {
        this.orderMemberLevelList = orderMemberLevelList;
    }

    public List<Integer> getGiftQualificationList() {
        return giftQualificationList;
    }

    public void setGiftQualificationList(List<Integer> giftQualificationList) {
        this.giftQualificationList = giftQualificationList;
    }

    public List<String> getThirdPartyInterfaceList() {
        return thirdPartyInterfaceList;
    }

    public void setThirdPartyInterfaceList(List<String> thirdPartyInterfaceList) {
        this.thirdPartyInterfaceList = thirdPartyInterfaceList;
    }

    public List<GiftCampaignConditionSkuVO> getGiftCampaignConditionSkuVOList() {
        return giftCampaignConditionSkuVOList;
    }

    public void setGiftCampaignConditionSkuVOList(List<GiftCampaignConditionSkuVO> giftCampaignConditionSkuVOList) {
        this.giftCampaignConditionSkuVOList = giftCampaignConditionSkuVOList;
    }

    public List<GiftCampaignRuleSkuVO> getGiftCampaignRuleSkuVOList() {
        return giftCampaignRuleSkuVOList;
    }

    public void setGiftCampaignRuleSkuVOList(List<GiftCampaignRuleSkuVO> giftCampaignRuleSkuVOList) {
        this.giftCampaignRuleSkuVOList = giftCampaignRuleSkuVOList;
    }

}

==> beast-privilege-api-2.6.9-GS-20230713.032941-1-sources.jar: com/thebeastshop/privilege/vo/GiftCampaignVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class GiftCampaignVO implements Serializable {
    private Integer id;
    private String name;
    private Date startDate;
    private Date endDate;
    private String remark;
    private Integer status;
    private String systemDefault;
    private String orderChannelCode;
    private String orderType;
    private String orderBusinessType;
    private String memberLevel;
    private Date orderStartDate;
    private Date orderEndDate;
    private Date payStartDate;
    private Date payEndDate;

    private Integer hasJoin;
    private String giftQualification;
    private String thirdPartyInterface;
    private String orderRemark;
    private Boolean isFuzzyMatch;
    private Integer scope;
    private Integer giftWay;
    private Integer randomNum;
    private Integer totalNum;
    private Integer singleLimit;
    private Integer giftCondition;
    private Integer stepRule;
    private Integer createUserId;
    private String createUserName;
    private Date createTime;
    private Date updateTime;
    private String giftWayText;


    private Integer sendFinishStop;

    private Integer stepAmountCompute;




    private List<String> orderChannelCodeList;
    private List<Integer> orderTypeList;
    private List<Integer> orderBusinessTypeList;
    private List<Integer> memberLevelList;
    private List<Integer> giftQualificationList;
    private List<String>  thirdPartyInterfaceList;


    private List<GiftCampaignConditionSkuVO> giftCampaignApplySkuVOList;
    private List<GiftCampaignConditionSkuVO> giftCampaignExcludeSkuVOList;

    private List<GiftCampaignRuleSkuVO> giftCampaignRuleSkuVOList;
    private List<GiftCampaignRuleGroupVO> giftCampaignRuleGroupVOList;



    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getSystemDefault() {
        return systemDefault;
    }

    public void setSystemDefault(String systemDefault) {
        this.systemDefault = systemDefault;
    }

    public String getOrderChannelCode() {
        return orderChannelCode;
    }

    public void setOrderChannelCode(String orderChannelCode) {
        this.orderChannelCode = orderChannelCode;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderBusinessType() {
        return orderBusinessType;
    }

    public void setOrderBusinessType(String orderBusinessType) {
        this.orderBusinessType = orderBusinessType;
    }

    public String getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(String memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Date getOrderStartDate() {
        return orderStartDate;
    }

    public void setOrderStartDate(Date orderStartDate) {
        this.orderStartDate = orderStartDate;
    }

    public Date getOrderEndDate() {
        return orderEndDate;
    }

    public void setOrderEndDate(Date orderEndDate) {
        this.orderEndDate = orderEndDate;
    }

    public Date getPayStartDate() {
        return payStartDate;
    }

    public void setPayStartDate(Date payStartDate) {
        this.payStartDate = payStartDate;
    }

    public Date getPayEndDate() {
        return payEndDate;
    }

    public void setPayEndDate(Date payEndDate) {
        this.payEndDate = payEndDate;
    }


    public Integer getHasJoin() {
        return hasJoin;
    }

    public void setHasJoin(Integer hasJoin) {
        this.hasJoin = hasJoin;
    }


    public String getGiftQualification() {
        return giftQualification;
    }

    public void setGiftQualification(String giftQualification) {
        this.giftQualification = giftQualification;
    }

    public String getThirdPartyInterface() {
        return thirdPartyInterface;
    }

    public void setThirdPartyInterface(String thirdPartyInterface) {
        this.thirdPartyInterface = thirdPartyInterface;
    }

    public String getOrderRemark() {
        return orderRemark;
    }

    public void setOrderRemark(String orderRemark) {
        this.orderRemark = orderRemark;
    }

    public Boolean getIsFuzzyMatch() {
        return isFuzzyMatch;
    }

    public void setIsFuzzyMatch(Boolean fuzzyMatch) {
        isFuzzyMatch = fuzzyMatch;
    }

    public Integer getScope() {
        return scope;
    }

    public void setScope(Integer scope) {
        this.scope = scope;
    }

    public Integer getGiftWay() {
        return giftWay;
    }

    public void setGiftWay(Integer giftWay) {
        this.giftWay = giftWay;
    }

    public Integer getRandomNum() {
        return randomNum;
    }

    public void setRandomNum(Integer randomNum) {
        this.randomNum = randomNum;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getSingleLimit() {
        return singleLimit;
    }

    public void setSingleLimit(Integer singleLimit) {
        this.singleLimit = singleLimit;
    }

    public Integer getGiftCondition() {
        return giftCondition;
    }

    public void setGiftCondition(Integer giftCondition) {
        this.giftCondition = giftCondition;
    }

    public Integer getStepRule() {
        return stepRule;
    }

    public void setStepRule(Integer stepRule) {
        this.stepRule = stepRule;
    }

    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getGiftWayText() {
        return giftWayText;
    }

    public void setGiftWayText(String giftWayText) {
        this.giftWayText = giftWayText;
    }

    public Integer getSendFinishStop() {
        return sendFinishStop;
    }

    public void setSendFinishStop(Integer sendFinishStop) {
        this.sendFinishStop = sendFinishStop;
    }

    public Integer getStepAmountCompute() {
        return stepAmountCompute;
    }

    public void setStepAmountCompute(Integer stepAmountCompute) {
        this.stepAmountCompute = stepAmountCompute;
    }
    public List<String> getOrderChannelCodeList() {
        return orderChannelCodeList;
    }

    public void setOrderChannelCodeList(List<String> orderChannelCodeList) {
        this.orderChannelCodeList = orderChannelCodeList;
    }

    public List<Integer> getOrderTypeList() {
        return orderTypeList;
    }

    public void setOrderTypeList(List<Integer> orderTypeList) {
        this.orderTypeList = orderTypeList;
    }

    public List<Integer> getOrderBusinessTypeList() {
        return orderBusinessTypeList;
    }

    public void setOrderBusinessTypeList(List<Integer> orderBusinessTypeList) {
        this.orderBusinessTypeList = orderBusinessTypeList;
    }

    public List<Integer> getMemberLevelList() {
        return memberLevelList;
    }

    public void setMemberLevelList(List<Integer> memberLevelList) {
        this.memberLevelList = memberLevelList;
    }
    public List<Integer> getGiftQualificationList() {
        return giftQualificationList;
    }

    public void setGiftQualificationList(List<Integer> giftQualificationList) {
        this.giftQualificationList = giftQualificationList;
    }

    public List<String> getThirdPartyInterfaceList() {
        return thirdPartyInterfaceList;
    }

    public void setThirdPartyInterfaceList(List<String> thirdPartyInterfaceList) {
        this.thirdPartyInterfaceList = thirdPartyInterfaceList;
    }

    public List<GiftCampaignConditionSkuVO> getGiftCampaignApplySkuVOList() {
        return giftCampaignApplySkuVOList;
    }

    public void setGiftCampaignApplySkuVOList(List<GiftCampaignConditionSkuVO> giftCampaignApplySkuVOList) {
        this.giftCampaignApplySkuVOList = giftCampaignApplySkuVOList;
    }

    public List<GiftCampaignConditionSkuVO> getGiftCampaignExcludeSkuVOList() {
        return giftCampaignExcludeSkuVOList;
    }

    public void setGiftCampaignExcludeSkuVOList(List<GiftCampaignConditionSkuVO> giftCampaignExcludeSkuVOList) {
        this.giftCampaignExcludeSkuVOList = giftCampaignExcludeSkuVOList;
    }

    public List<GiftCampaignRuleSkuVO> getGiftCampaignRuleSkuVOList() {
        return giftCampaignRuleSkuVOList;
    }

    public void setGiftCampaignRuleSkuVOList(List<GiftCampaignRuleSkuVO> giftCampaignRuleSkuVOList) {
        this.giftCampaignRuleSkuVOList = giftCampaignRuleSkuVOList;
    }

    public List<GiftCampaignRuleGroupVO> getGiftCampaignRuleGroupVOList() {
        return giftCampaignRuleGroupVOList;
    }

    public void setGiftCampaignRuleGroupVOList(List<GiftCampaignRuleGroupVO> giftCampaignRuleGroupVOList) {
        this.giftCampaignRuleGroupVOList = giftCampaignRuleGroupVOList;
    }

}
